############################################################################
##
## Copyright (c) 2000 BalaBit IT Ltd, Budapest, Hungary
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
##
## $Id: Finger.py,v 1.1 2001/01/05 11:04:18 bazsi Exp $
##
## Author  : Bazsi
## Auditor : 
## Last version: 1.10
## Notes:
##
############################################################################

from Zorp import *
from Proxy import Proxy

class FingerProxy(Proxy):
	"""Wrapper class for the Finger protocol proxy implemented by Zorp.
	
	This proxy implements the finger protocol as specified in rfc1288.
	
	Usage:
	
	  You can limit username length and response length by setting
	  various attributes. Finger proxy also has the capability
	  of limiting the number of hosts in a request, like:
	  
	    finger bazsi@balabit@tudor
	    
	  which normally results in fingering bazsi@tudor performed by
	  the host balabit. By default this proxy strips off everything
	  after and including the first `@' character, you can change
	  this behaviour by setting max_hop_count to a nonzero value.
	  
	Attributes:
	
	  max_hop_count --
	  max_username_length --
	  max_line_length --
	  strict_username_check --
	
	"""
	def __init__(self, session):
		"""Initialize a FingerProxy instance.

		Create and set up a FingerProxy instance.

		Arguments:

		  self -- this instance
		  
		  session -- session this instance belongs to
		
		"""
		Proxy.__init__(self, "finger", session)

