############################################################################
##
## Copyright (c) 2000 BalaBit IT Ltd, Budapest, Hungary
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
##
## $Id: Connector.py,v 1.20 2000/12/21 16:14:14 bazsi Exp $
##
## Author  : Bazsi
## Auditor : kisza
## Last version: 1.7
## Notes:
##
############################################################################

import Zorp

class Connect:
	"""A wrapper class around the ZorpConnect class implemented in C.
	   
	Attributes:
	
	  local	  -- Address of local end of the connection
	  
	  remote  -- Address where we connect
	  
	  connect -- a Zorp.Connect object
	"""

	def __init__(self, local, remote, callback = None):
		"""Initializes a Connect instance.
		
		Sets the attributes based on constructor parameters,
		and start connecting in a separate thread if
		callback is not None.

		Arguments:

		  self     -- this instance
		  
		  local    -- Address of local end of the connection
		  
		  remote   -- Address where we connect
		  
		  callback -- Callback to be called when the connection is
		              established. If this is None blockingConnect
			      should be called.

		   	
		"""
		self.local = local
		self.remote = remote
		self.connect = Zorp.Connect(local, remote, callback)
		if callback != None:
			self.connect.start()
			self.local = self.connect.local

			
	def blockingConnect(self):
		"""Establish a connection in blocking mode.
		
		Establishes the connection and returns its fd.
		
		Arguments:
		
		  self  -- this instance
		  
		Returns:
		
		  the fd 
		"""
		
		self.connect.start()
		self.local = self.connect.local
		return self.connect.block()
		
	def destroy(self):
		"""Destroy this connector instance.
		
		Stop connecting and destroy the underlying ZorpConnect
		instance.
		   
		Arguments:
		
		  self -- instance
		"""
		self.connect.destroy()
