############################################################################
##
## Copyright (c) 2000 BalaBit IT Ltd, Budapest, Hungary
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
##
## $Id: Service.py,v 1.24 2000/12/28 17:45:07 bazsi Exp $
##
## Author  : Bazsi
## Auditor : kisza
## Last version: 1.9
## Notes:
##   - comments in English
##
############################################################################

from Stream import Stream
from Session import StackedSession
from Zorp import ServiceException

services = {}

class AbstractService:
	"""Encapsulates an abstract service.

	A service is something Zorp provides to its environment.

	Attributes:
	
	  name		-- The name of the service
	  
	  instance_id	-- the session serviced by the service

	"""
	
	def __init__(self, name):
		"""Initializes an AbstractService instance or a derivative.

		Sets attributes based on arguments.
		
		Arguments:

		  self  -- this instance
		  
		  name	--	The name of the service

		"""
		if services.has_key(name):
			raise ServiceException, "Duplicate service"
		services[name] = self
		self.name = name
		self.instance_id = 0
	
	def startInstance(self, session):
		"""Function to start an instance of this service.
		
		Abstract method to be implemented in derived classes.
		Should start an instance of the given service.
		   
		Arguments:

		  self          --      this instance
		  
		  session	--	start service within this session

		"""
		raise NotImplementedError
		
	def __str__(self):
		return self.name

class Service(AbstractService):
	"""
	
	Service encapsulates a firewall service going through the
	firewall. A service consists of a Proxy class, a chainer
	instance and an authenticator instance.
		
	Attributes:
	
	  chainer      -- The chainer class used for the service
	  
	  proxy_class  -- The proxy class used for the service
	  
	  auth	       -- Authentication handling class 
	                  (None if no authentication)
	"""
	chainer = None
	proxy_class = None
	auth = None

	def __init__(self, name, chainer, proxy_class, auth = None):
		"""Initializes a Service instance.
		   
		Arguments:
		
		  name	     -- Name of this service (used in access control)
		  
		  chainer    -- The chainer class used for the service
		  
		  proxy_class--	The proxy class used for the service
		  
		  auth	     -- Authentication handling class (None if
		                no authentication)
				(FIXME: not working currently)

		"""
		AbstractService.__init__(self, name)
		self.chainer = chainer
		self.proxy_class = proxy_class
		#self.labels = labels
		#self.auth = auth
	
		#if root == None:
		#	self.root_zone = root_zone
		#else:
		#	self.root_zone = root_zone

	def startInstance(self, session):
		"""Start an instance of this session.
		
		Called by the Listener to create an instance of this
		service.
		   
		Arguments:

		  self          --      this instance
		  
		  session	--	The session object
			
		Notes:
		
		  Authenticates the user, and starts a proxy using the
		  session 

		"""

		#if session.auth == None:
		#	session.auth = self.auth		
		#if session.auth != None and not session.auth.authenticate(session):
		#	raise Zorp.AuthException

		#Zorp.message(0, "auth_user=" + session.auth_user)
		
		session.name = self.name
		instance_id = self.instance_id
		
		# FIXME: handle wraparound
		self.instance_id = self.instance_id + 1
		
		session.setServiceInstance(instance_id)
		ss = StackedSession(session, self.chainer)
		ss.client_stream = Stream(ss.client_fd, ss.session_id + ": client")
		self.proxy_class(ss)
			
		return None
		
#
# Egy instance_class es param helyett egy mappingot vesz at, ami zonatol
# fuggoen mas es mas eredmenyt ad
#
#class MultiService(AbstractService):
#	def __init__(self, name
